@@ -9,15 +9,18 @@
 #include <QCommandLineParser>
 #include <QDBusMessage>
 #include <QIcon>
-#include <QNetworkAccessManager>
 #include <QProcess>
 #include <QSessionManager>
 #include <QStandardPaths>
 #include <QTimer>
 
+#ifdef Q_OS_WIN
+#include <Windows.h>
+#endif
+
 #include <KAboutData>
 #include <KDBusService>
-#include <KIO/AccessManager>
+#include <KIO/Global>
 #include <KLocalizedString>
 #include <KNotification>
 #include <KWindowSystem>
@@ -38,15 +41,14 @@ class DesktopDaemon : public Daemon
 public:
     DesktopDaemon(QObject *parent = nullptr)
         : Daemon(parent)
-        , m_nam(nullptr)
     {
-        qApp->setWindowIcon(QIcon(QStringLiteral(":/icons/kdeconnect/kdeconnect.svg")));
+        qApp->setWindowIcon(QIcon(QStringLiteral(":/icons/kdeconnect/kdeconnect.png")));
     }
 
     void askPairingConfirmation(Device *device) override
     {
         KNotification *notification = new KNotification(QStringLiteral("pairingRequest"), KNotification::NotificationFlag::Persistent);
-        QTimer::singleShot(PairingHandler::pairingTimeoutMsec(), notification, &KNotification::close);
+        QTimer::singleShot(PairingHandler::pairingTimeoutMsec, notification, &KNotification::close);
         notification->setIconName(QStringLiteral("dialog-information"));
         notification->setComponentName(QStringLiteral("kdeconnect"));
         notification->setTitle(QStringLiteral("KDE Connect"));
@@ -55,7 +57,7 @@ public:
         notification->setDefaultAction(i18n("Open"));
         notification->setActions(QStringList() << i18n("Accept") << i18n("Reject") << i18n("View key"));
         connect(notification, &KNotification::action1Activated, device, &Device::acceptPairing);
-        connect(notification, &KNotification::action2Activated, device, &Device::rejectPairing);
+        connect(notification, &KNotification::action2Activated, device, &Device::cancelPairing);
         QString deviceId = device->id();
         auto openSettings = [deviceId, notification] {
             OpenConfig oc;
@@ -73,14 +75,6 @@ public:
         KNotification::event(KNotification::Error, title, description);
     }
 
-    QNetworkAccessManager *networkAccessManager() override
-    {
-        if (!m_nam) {
-            m_nam = new KIO::Integration::AccessManager(this);
-        }
-        return m_nam;
-    }
-
     KJobTrackerInterface *jobTracker() override
     {
         return KIO::getJobTracker();
@@ -100,9 +94,6 @@ public:
     {
         QApplication::quit();
     }
-
-private:
-    QNetworkAccessManager *m_nam;
 };
 
 // Copied from plasma-workspace/libkworkspace/kworkspace.cpp
@@ -130,6 +121,14 @@ static void detectPlatform(int argc, char **argv)
 
 int main(int argc, char *argv[])
 {
+#ifdef Q_OS_WIN
+    // If ran from a console, redirect the output there
+    if (AttachConsole(ATTACH_PARENT_PROCESS)) {
+        freopen("CONOUT$", "w", stdout);
+        freopen("CONOUT$", "w", stderr);
+    }
+#endif
+
     detectPlatform(argc, argv);
     QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
@@ -146,9 +145,11 @@ int main(int argc, char *argv[])
     QCommandLineParser parser;
     QCommandLineOption replaceOption({QStringLiteral("replace")}, i18n("Replace an existing instance"));
     parser.addOption(replaceOption);
+#ifdef Q_OS_MAC
     QCommandLineOption macosPrivateDBusOption({QStringLiteral("use-private-dbus")},
                                               i18n("Launch a private D-Bus daemon with kdeconnectd (macOS test-purpose only)"));
     parser.addOption(macosPrivateDBusOption);
+#endif
     aboutData.setupCommandLine(&parser);
 
     parser.process(app);
