@@ -11,6 +11,7 @@
 #include <QGuiApplication>
 #include <QQmlContext>
 #include <QQmlEngine>
+#include <devicespluginfilterproxymodel.h>
 
 #include "objectfactory.h"
 #include "responsewaiter.h"
@@ -25,7 +26,7 @@
 #include <pluginmodel.h>
 #include <remotecommandsmodel.h>
 #include <remotesinksmodel.h>
-#if WITH_WAYLAND == 1
+#if WITH_WAYLAND
 #include "pointerlockerwayland.h"
 #endif
 
@@ -51,6 +52,7 @@ void KdeConnectDeclarativePlugin::registerTypes(const char *uri)
     qmlRegisterType<RemoteCommandsModel>(uri, 1, 0, "RemoteCommandsModel");
     qmlRegisterType<DBusAsyncResponse>(uri, 1, 0, "DBusAsyncResponse");
     qmlRegisterType<DevicesSortProxyModel>(uri, 1, 0, "DevicesSortProxyModel");
+    qmlRegisterType<DevicesPluginFilterProxyModel>(uri, 1, 0, "DevicesPluginFilterProxyModel");
     qmlRegisterType<RemoteSinksModel>(uri, 1, 0, "RemoteSinksModel");
     qmlRegisterType<PluginModel>(uri, 1, 0, "PluginModel");
     qmlRegisterType<KdeConnectPluginConfig>(uri, 1, 0, "KdeConnectPluginConfig");
@@ -62,6 +64,7 @@ void KdeConnectDeclarativePlugin::registerTypes(const char *uri)
                                                                0,
                                                                "FindMyPhoneDbusInterface",
                                                                QStringLiteral("You're not supposed to instantiate interfaces"));
+    qmlRegisterUncreatableType<ClipboardDbusInterface>(uri, 1, 0, "ClipboardDbusInterface", QStringLiteral("You're not supposed to instantiate interfaces"));
     qmlRegisterUncreatableType<RemoteKeyboardDbusInterface>(uri,
                                                             1,
                                                             0,
@@ -86,7 +89,7 @@ void KdeConnectDeclarativePlugin::registerTypes(const char *uri)
     });
     qmlRegisterSingletonType<AbstractPointerLocker>("org.kde.kdeconnect", 1, 0, "PointerLocker", [](QQmlEngine *, QJSEngine *) -> QObject * {
         AbstractPointerLocker *ret;
-#if WITH_WAYLAND == 1
+#if WITH_WAYLAND
         if (qGuiApp->platformName() == QLatin1String("wayland"))
             ret = new PointerLockerWayland;
         else
@@ -111,6 +114,7 @@ void KdeConnectDeclarativePlugin::registerTypes(const char *uri)
     registerFactory<FindMyPhoneDeviceDbusInterface>(uri, "FindMyPhoneDbusInterfaceFactory");
     registerFactory<SftpDbusInterface>(uri, "SftpDbusInterfaceFactory");
     registerFactory<RemoteKeyboardDbusInterface>(uri, "RemoteKeyboardDbusInterfaceFactory");
+    registerFactory<ClipboardDbusInterface>(uri, "ClipboardDbusInterfaceFactory");
     registerFactory<MprisDbusInterface>(uri, "MprisDbusInterfaceFactory");
     registerFactory<RemoteControlDbusInterface>(uri, "RemoteControlDbusInterfaceFactory");
     registerFactory<LockDeviceDbusInterface>(uri, "LockDeviceDbusInterfaceFactory");
