@@ -22,7 +22,6 @@ MprisRemotePlayer::MprisRemotePlayer(QString id, MprisRemotePlugin *plugin)
     , m_canPause(true)
     , m_canGoPrevious(true)
     , m_canGoNext(true)
-    , m_nowPlaying()
     , m_volume(50)
     , m_length(0)
     , m_lastPosition(0)
@@ -54,30 +53,27 @@ void MprisRemotePlayer::parseNetworkPacket(const NetworkPacket &np)
     bool trackInfoHasChanged = false;
 
     // Track properties
-    QString newNowPlaying = np.get<QString>(QStringLiteral("nowPlaying"), m_nowPlaying);
     QString newTitle = np.get<QString>(QStringLiteral("title"), m_title);
     QString newArtist = np.get<QString>(QStringLiteral("artist"), m_artist);
     QString newAlbum = np.get<QString>(QStringLiteral("album"), m_album);
     int newLength = np.get<int>(QStringLiteral("length"), m_length);
 
     // Check if they changed
-    if (newNowPlaying != m_nowPlaying || newTitle != m_title || newArtist != m_artist || newAlbum != m_album || newLength != m_length) {
+    if (newTitle != m_title || newArtist != m_artist || newAlbum != m_album || newLength != m_length) {
         trackInfoHasChanged = true;
+        m_title = newTitle;
+        m_artist = newArtist;
+        m_album = newAlbum;
+        m_length = newLength;
         Q_EMIT trackInfoChanged();
     }
-    // Set the new values
-    m_nowPlaying = newNowPlaying;
-    m_title = newTitle;
-    m_artist = newArtist;
-    m_album = newAlbum;
-    m_length = newLength;
 
     // Check volume changes
     int newVolume = np.get<int>(QStringLiteral("volume"), m_volume);
     if (newVolume != m_volume) {
+        m_volume = newVolume;
         Q_EMIT volumeChanged();
     }
-    m_volume = newVolume;
 
     if (np.has(QStringLiteral("pos"))) {
         // Check position
@@ -86,8 +82,8 @@ void MprisRemotePlayer::parseNetworkPacket(const NetworkPacket &np)
         m_lastPosition = newLastPosition;
         m_lastPositionTime = QDateTime::currentMSecsSinceEpoch();
 
-        // Only consider it seeking if the position changed more than 1 second, and the track has not changed
-        if (qAbs(positionDiff) >= 1000 && !trackInfoHasChanged) {
+        // Only consider it seeking if the position changed more than 1 second or the track has changed
+        if (qAbs(positionDiff) >= 1000 || trackInfoHasChanged) {
             Q_EMIT positionChanged();
         }
     }
@@ -95,9 +91,9 @@ void MprisRemotePlayer::parseNetworkPacket(const NetworkPacket &np)
     // Check if we started/stopped playing
     bool newPlaying = np.get<bool>(QStringLiteral("isPlaying"), m_playing);
     if (newPlaying != m_playing) {
+        m_playing = newPlaying;
         Q_EMIT playingChanged();
     }
-    m_playing = newPlaying;
 
     // Control properties
     bool newCanSeek = np.get<bool>(QStringLiteral("canSeek"), m_canSeek);
@@ -105,17 +101,14 @@ void MprisRemotePlayer::parseNetworkPacket(const NetworkPacket &np)
     bool newCanPause = np.get<bool>(QStringLiteral("canPause"), m_canPause);
     bool newCanGoPrevious = np.get<bool>(QStringLiteral("canGoPrevious"), m_canGoPrevious);
     bool newCanGoNext = np.get<bool>(QStringLiteral("canGoNext"), m_canGoNext);
-
-    // Check if they changed
     if (newCanSeek != m_canSeek || newCanPlay != m_canPlay || newCanPause != m_canPause || newCanGoPrevious != m_canGoPrevious || newCanGoNext != m_canGoNext) {
+        m_canSeek = newCanSeek;
+        m_canPlay = newCanPlay;
+        m_canPause = newCanPause;
+        m_canGoPrevious = newCanGoPrevious;
+        m_canGoNext = newCanGoNext;
         Q_EMIT controlsChanged();
     }
-    // Set the new values
-    m_canSeek = newCanSeek;
-    m_canPlay = newCanPlay;
-    m_canPause = newCanPause;
-    m_canGoPrevious = newCanGoPrevious;
-    m_canGoNext = newCanGoNext;
 }
 
 long MprisRemotePlayer::position() const
@@ -148,11 +141,6 @@ bool MprisRemotePlayer::playing() const
     return m_playing;
 }
 
-QString MprisRemotePlayer::nowPlaying() const
-{
-    return m_nowPlaying;
-}
-
 QString MprisRemotePlayer::title() const
 {
     return m_title;
