@@ -10,7 +10,8 @@
 class MprisRemotePlayer;
 class MprisRemotePlugin;
 
-class MprisRemotePlayerMediaPlayer2 : public QDBusAbstractAdaptor {
+class MprisRemotePlayerMediaPlayer2 : public QDBusAbstractAdaptor
+{
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.mpris.MediaPlayer2")
 
