@@ -9,30 +9,33 @@
 #include <KLocalizedString>
 #include <KPluginFactory>
 
-#include <QDebug>
 #include <QDBusConnection>
+#include <QDebug>
 
-#include <core/device.h>
 #include <core/daemon.h>
+#include <core/device.h>
 
 #include "plugin_ping_debug.h"
 
 K_PLUGIN_CLASS_WITH_JSON(PingPlugin, "kdeconnect_ping.json")
 
-PingPlugin::PingPlugin(QObject* parent, const QVariantList& args)
+PingPlugin::PingPlugin(QObject *parent, const QVariantList &args)
     : KdeConnectPlugin(parent, args)
 {
-//     qCDebug(KDECONNECT_PLUGIN_PING) << "Ping plugin constructor for device" << device()->name();
+    //     qCDebug(KDECONNECT_PLUGIN_PING) << "Ping plugin constructor for device" << device()->name();
 }
 
 PingPlugin::~PingPlugin()
 {
-//     qCDebug(KDECONNECT_PLUGIN_PING) << "Ping plugin destructor for device" << device()->name();
+    //     qCDebug(KDECONNECT_PLUGIN_PING) << "Ping plugin destructor for device" << device()->name();
 }
 
-bool PingPlugin::receivePacket(const NetworkPacket& np)
+bool PingPlugin::receivePacket(const NetworkPacket &np)
 {
-    Daemon::instance()->sendSimpleNotification(QStringLiteral("pingReceived"), device()->name(), np.get<QString>(QStringLiteral("message"),i18n("Ping!")), QStringLiteral("dialog-ok"));
+    Daemon::instance()->sendSimpleNotification(QStringLiteral("pingReceived"),
+                                               device()->name(),
+                                               np.get<QString>(QStringLiteral("message"), i18n("Ping!")),
+                                               QStringLiteral("dialog-ok"));
 
     return true;
 }
@@ -44,7 +47,7 @@ void PingPlugin::sendPing()
     qCDebug(KDECONNECT_PLUGIN_PING) << "sendPing:" << success;
 }
 
-void PingPlugin::sendPing(const QString& customMessage)
+void PingPlugin::sendPing(const QString &customMessage)
 {
     NetworkPacket np(PACKET_TYPE_PING);
     if (!customMessage.isEmpty()) {
@@ -60,4 +63,3 @@ QString PingPlugin::dbusPath() const
 }
 
 #include "pingplugin.moc"
-
