@@ -23,8 +23,7 @@
 
 K_PLUGIN_CLASS_WITH_JSON(SftpPlugin, "kdeconnect_sftp.json")
 
-static const QSet<QString> fields_c = QSet<QString>() << QStringLiteral("ip") << QStringLiteral("port") << QStringLiteral("user") << QStringLiteral("port")
-                                                      << QStringLiteral("path");
+static const QSet<QString> fields_c = QSet<QString>() << QStringLiteral("user") << QStringLiteral("port") << QStringLiteral("path");
 
 struct SftpPlugin::Pimpl {
     Pimpl()
@@ -40,8 +39,8 @@ struct SftpPlugin::Pimpl {
 SftpPlugin::SftpPlugin(QObject *parent, const QVariantList &args)
     : KdeConnectPlugin(parent, args)
     , d(new Pimpl())
+    , deviceId(device()->id())
 {
-    deviceId = device()->id();
     addToDolphin();
     qCDebug(KDECONNECT_PLUGIN_SFTP) << "Created device:" << device()->name();
 }
@@ -64,10 +63,13 @@ void SftpPlugin::addToDolphin()
 void SftpPlugin::removeFromDolphin()
 {
     QUrl kioUrl(QStringLiteral("kdeconnect://") + deviceId + QStringLiteral("/"));
-    QModelIndex index = d->m_placesModel.closestItem(kioUrl);
-    while (index.row() != -1) {
-        d->m_placesModel.removePlace(index);
-        index = d->m_placesModel.closestItem(kioUrl);
+    for (int i = 0; i < d->m_placesModel.rowCount(); ++i) {
+        QModelIndex index = d->m_placesModel.index(i, 0);
+        QUrl url = d->m_placesModel.url(index);
+        if (url == kioUrl) {
+            d->m_placesModel.removePlace(index);
+            --i;
+        }
     }
 }
 
