@@ -187,6 +187,8 @@ public:
         HANDLE threadHandle = CreateThread(NULL, 0, releaseRemovedDevice, &data, 0, &threadId);
         CloseHandle(threadHandle);
 
+        enclosing.sendSinkList();
+
         return S_OK;
     }
 
@@ -194,14 +196,20 @@ public:
     {
         if (dwNewState == DEVICE_STATE_UNPLUGGED)
             return OnDeviceRemoved(pwstrDeviceId);
-
-        enclosing.sendSinkList();
         return S_OK;
     }
 
     HRESULT STDMETHODCALLTYPE OnPropertyValueChanged(LPCWSTR pwstrDeviceId, const PROPERTYKEY key) override
     {
-        enclosing.sendSinkList();
+        // This callback is supper spammy. Care only about name and description changes.
+        if (IsEqualPropertyKey(key, PKEY_Device_FriendlyName)) {
+            enclosing.sendSinkList();
+        }
+#ifndef __MINGW32__
+        else if (IsEqualPropertyKey(key, PKEY_Device_DeviceDesc)) {
+            enclosing.sendSinkList();
+        }
+#endif
         return S_OK;
     }
 
@@ -227,6 +235,11 @@ SystemvolumePlugin::SystemvolumePlugin(QObject *parent, const QVariantList &args
 SystemvolumePlugin::~SystemvolumePlugin()
 {
     if (valid) {
+        for (auto &entry : sinkList) {
+            entry.first->UnregisterControlChangeNotify(entry.second);
+            entry.second->Release();
+            entry.first->Release();
+        }
         deviceEnumerator->UnregisterEndpointNotificationCallback(deviceCallback);
         deviceEnumerator->Release();
         deviceEnumerator = nullptr;
@@ -288,12 +301,12 @@ bool SystemvolumePlugin::sendSinkList()
 
         deviceProperties->GetValue(PKEY_Device_FriendlyName, &deviceProperty);
         name = QString::fromWCharArray(deviceProperty.pwszVal);
-        // PropVariantClear(&deviceProperty);
+        PropVariantClear(&deviceProperty);
 
 #ifndef __MINGW32__
         deviceProperties->GetValue(PKEY_Device_DeviceDesc, &deviceProperty);
         desc = QString::fromWCharArray(deviceProperty.pwszVal);
-        // PropVariantClear(&deviceProperty);
+        PropVariantClear(&deviceProperty);
 #else
         desc = name;
 #endif
@@ -404,31 +417,18 @@ bool SystemvolumePlugin::receivePacket(const NetworkPacket &np)
     } else {
         QString name = np.get<QString>(QStringLiteral("name"));
 
-        if (sinkList.contains(name)) {
-            // unregister ControlChangeNotify before doing any changes to a sink
-            HRESULT unregisterSuccess = E_POINTER;
-            auto sinkListIterator = this->sinkList.find(name);
+        auto sinkListIterator = this->sinkList.find(name);
+        if (sinkListIterator != this->sinkList.end()) {
             auto &sink = sinkListIterator.value();
-            if (!(sinkListIterator == this->sinkList.end())) {
-                unregisterSuccess = sink.first->UnregisterControlChangeNotify(sink.second);
-            }
 
             if (np.has(QStringLiteral("volume"))) {
-                float currentVolume;
-                sink.first->GetMasterVolumeLevelScalar(&currentVolume);
                 float requestedVolume = (float)np.get<int>(QStringLiteral("volume"), 100) / 100;
-                if (currentVolume != requestedVolume) {
-                    sinkList[name].first->SetMasterVolumeLevelScalar(requestedVolume, NULL);
-                }
+                sinkList[name].first->SetMasterVolumeLevelScalar(requestedVolume, NULL);
             }
 
             if (np.has(QStringLiteral("muted"))) {
-                BOOL currentMuteStatus;
-                sink.first->GetMute(&currentMuteStatus);
                 BOOL requestedMuteStatus = np.get<bool>(QStringLiteral("muted"), false);
-                if (currentMuteStatus != requestedMuteStatus) {
-                    sinkList[name].first->SetMute(requestedMuteStatus, NULL);
-                }
+                sinkList[name].first->SetMute(requestedMuteStatus, NULL);
             }
 
             if (np.has(QStringLiteral("enabled"))) {
@@ -441,16 +441,10 @@ bool SystemvolumePlugin::receivePacket(const NetworkPacket &np)
                 // get current sink's device ID
                 QString qDefaultId = QString::fromWCharArray(defaultId);
                 QString currentDeviceId = idToNameMap.key(name);
-
-                if ((bool)qDefaultId.compare(currentDeviceId)) {
+                if (qDefaultId != currentDeviceId) {
                     setDefaultAudioPlaybackDevice(name, np.get<bool>(QStringLiteral("enabled")));
                 }
             }
-
-            // re-register ControlChangeNotify in case we unregistered it
-            if (unregisterSuccess == S_OK) {
-                sink.first->RegisterControlChangeNotify(sink.second);
-            }
         }
     }
     return true;
